@@ -4,15 +4,14 @@ VE.Jk.B.Corr.Hajek <- function(VecY.s, VecX.s, VecPk.s)
   if(! is.vector(VecX.s)             ){stop("VecX.s must be a vector.")                                       }
   if(! is.vector(VecPk.s)            ){stop("VecPk.s must be a vector.")                                      }
   n                                   <- length(VecY.s)
-  if(n != as.integer(length(VecPk.s))){stop("The lengths of VecY.s and VecPk.s are different.")               }
-  if(n != as.integer(length(VecX.s)) ){stop("The lengths of VecY.s and VecX.s are different.")                }
+  if(n != length(VecPk.s)            ){stop("The lengths of VecY.s and VecPk.s are different.")               }
+  if(n != length(VecX.s)             ){stop("The lengths of VecY.s and VecX.s are different.")                }
   if(any(is.na(VecPk.s))             ){stop("There are missing values in VecPk.s.")                           }
   if(any(VecPk.s<=0|VecPk.s>1)       ){stop("There are invalid values in VecPk.s.")                           }
   if(any(is.na(VecY.s))              ){stop("There are missing values in VecY.s.")                            }
   if(any(is.na(VecX.s))              ){stop("There are missing values in VecX.s.")                            }
-  if(any(VecX.s==0)                  ){stop("There are zero values in VecX.s. Division by zero is undefined.")}
   VecEstTheta_k                       <- .C("Est_Corr_Hajek_Excluding_All_Elements",
-                                             as.double(VecY.s), 
+                                             as.double(VecY.s),
                                              as.double(VecX.s), 
                                              as.double(VecPk.s), 
                                              as.integer(n), 
